Struct diem_secure_push_metrics::MetricsPusher[][src]

pub struct MetricsPusher { /* fields omitted */ }
MetricsPusher provides a function to push a list of Metrics to a configurable pushgateway endpoint.

Implementations

start starts a new thread and periodically pushes the metrics to a pushgateway endpoint